Temp

Struct Temp 

pub struct Temp(/* private fields */);
Integrated temperature sensor.

Implementations

Source

impl Temp

pub fn new(raw: TEMP) -> Self

Creates a new Temp, taking ownership of the temperature sensor’s register block.

pub fn measure(&mut self) -> I30F2

Starts a new measurement and blocks until completion.

If a measurement was already started, it will be canceled.

pub fn start_measurement(&mut self)

Kicks off a temperature measurement.

The measurement can be retrieved by calling read.

pub fn stop_measurement(&mut self)

Cancels an in-progress temperature measurement.

pub fn read(&mut self) -> Result<I30F2, Void>

Tries to read a started measurement (non-blocking).

Before calling this, start_measurement must be called.

Returns the measured temperature in °C.