pub struct Temp(/* private fields */);Expand description
Integrated temperature sensor.
Implementations
Sourceimpl Temp
impl Temp
Sourcepub fn new(raw: TEMP) -> Self
pub fn new(raw: TEMP) -> Self
Creates a new Temp, taking ownership of the temperature sensor’s register block.
Sourcepub fn measure(&mut self) -> I30F2
pub fn measure(&mut self) -> I30F2
Starts a new measurement and blocks until completion.
If a measurement was already started, it will be canceled.
Sourcepub fn start_measurement(&mut self)
pub fn start_measurement(&mut self)
Kicks off a temperature measurement.
The measurement can be retrieved by calling read.
Sourcepub fn stop_measurement(&mut self)
pub fn stop_measurement(&mut self)
Cancels an in-progress temperature measurement.